<?php

/**
 * @file
 * Contains Drupal\mollom\Entity\Form.
 *
 * This contains a form that is protected by Mollom.
 */

namespace Drupal\mollom\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\mollom\Controller\FormController;

/**
 * Defines the form entity.
 *
 * @ingroup mollom
 *
 * @ConfigEntityType(
 *   id = "mollom_form",
 *   label = @Translation("Mollom Form Configuration"),
 *   handlers = {
 *     "storage" = "Drupal\Core\Config\Entity\ConfigEntityStorage",
 *     "list_builder" = "Drupal\mollom\Controller\FormListBuilder",
 *     "form" = {
 *       "add" = "Drupal\mollom\Form\FormAdd",
 *       "edit" = "Drupal\mollom\Form\FormEdit",
 *       "delete" = "Drupal\mollom\Form\FormDelete",
 *     },
 *   },
 *   admin_permission = "administer mollom",
 *   config_prefix = "form",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *   },
 *   links = {
 *     "edit-form" = "/admin/config/content/mollom/form/{mollom_form}/edit",
 *     "delete-form" = "/admin/config/content/mollom/form/{mollom_form}/delete",
 *   }
 * )
 */
class Form extends ConfigEntityBase implements FormInterface {

  /**
   * The form ID.
   *
   * @var string
   */
  public $id;

  /**
   * The form UUID.
   *
   * @var string
   */
  public $uuid;

  /**
   * The form label.
   *
   * @var string
   */
  public $label;

  /**
   * The form checks.
   *
   * @var string
   */
  public $checks;

  /**
   * The form mode.
   *
   * @var string
   */
  public $mode;

  /**
   * The form fields to analyze.
   *
   * @var array
   */
  public $enabled_fields;

  /**
   * The strictness of the analyzer.
   *
   * @var string
   */
  public $strictness;

  /**
   * What to do if Mollom is not sure.
   *
   * @var string
   */
  public $unsure;

  /**
   * What to do if Mollom identified it as spam.
   *
   * @var string
   */
  public $discard;

  /**
   * Stored mapping of the Drupal fields to Mollom fields.
   *
   * @var array
   */
  public $mapping;

  /**
   * The module that manages the protected form.
   *
   * @var string
   */
  public $module;

  /**
   * The entity of the protected form.
   *
   * @var string
   */
  public $entity;

  /**
   * The entity bundle of the protected form.
   *
   * @var string
   */
  public $bundle;

  /**
   * {@inheritDoc}
   */
  public function loadMollomFormInfo() {
    // Get site-specific protection configuration.
    if (empty($this->id)) {
      return get_object_vars($this);
    }
    $mollom_form = $this->toArray();
    // Attach form registry information.
    $form_info = FormController::getProtectedFormDetails($mollom_form['id'], $mollom_form['module']);
    $mollom_form += $form_info;
    return $mollom_form;
  }
}
